@@ -130,6 +130,17 @@ plot.prior <- function(x, plot_type = "base",
   }
 
 
+  # plot orthonormal priors
+  if(is.prior.orthonormal(x)){
+    plots <- .plot.prior.orthonormal(x = x, plot_type = plot_type, plot_data = plot_data, par_name = par_name, ...)
+    if(plot_type == "ggplot"){
+      return(plots)
+    }else{
+      return(invisible())
+    }
+  }
+
+
   # default prior plots
   if(is.prior.simple(x)){
     if(inherits(plot_data, "density.prior.simple")){
@@ -334,6 +345,49 @@ plot.prior <- function(x, plot_type = "base",
     return(plot)
   }
 }
+.plot.prior.orthonormal    <- function(x, plot_type, plot_data, par_name = NULL, ...){
+
+  # get default plot settings
+  dots      <- list(...)
+
+  xlim      <- attr(plot_data, "x_range")
+  ylim      <- attr(plot_data, "y_range")
+
+  short_name      <- if(is.null(dots[["short_name"]]))      FALSE else dots[["short_name"]]
+  parameter_names <- if(is.null(dots[["parameter_names"]])) FALSE else dots[["parameter_names"]]
+
+  main      <- if(!is.null(attr(plot_data, "steps"))) print(x, plot = TRUE, short_name = short_name, parameter_names = parameter_names) else ""
+  xlab      <- if(!is.null(attr(plot_data, "steps"))) bquote(omega["["*.(attr(plot_data, "steps")[1])*","~.(attr(plot_data, "steps")[2])*"]"])  else bquote("dif"*.(if(!is.null(par_name)){" "*bquote(.(par_name)~"~")})~.(print(x, plot = TRUE, short_name = short_name, parameter_names = parameter_names)))
+  ylab      <- "Density"
+
+  # add it to the user input if desired
+  if(is.null(dots[["main"]])) dots$main <-  main
+  if(is.null(dots[["xlab"]])) dots$xlab <-  xlab
+  if(is.null(dots[["ylab"]])) dots$ylab <-  ylab
+  if(is.null(dots[["xlim"]])) dots$xlim <-  xlim
+  if(is.null(dots[["ylim"]])) dots$ylim <-  ylim
+
+
+  if(plot_type == "base"){
+
+    .plot.prior_empty("simple", dots)
+    .lines.prior.orthonormal(plot_data, ...)
+    plot <- NULL
+
+  }else if(plot_type == "ggplot"){
+
+    plot <- .ggplot.prior_empty("simple", dots)
+    plot <- plot + .geom_prior.orthonormal(plot_data, ...)
+
+  }
+
+  # return the plots
+  if(plot_type == "base"){
+    return(invisible())
+  }else if(plot_type == "ggplot"){
+    return(plot)
+  }
+}
 
 .plot.prior_empty    <- function(type, dots = list(), ...){
 
@@ -605,8 +659,8 @@ lines.prior <- function(x, xlim = NULL, x_seq = NULL, x_range_quant = NULL, n_po
 
 
   # plot PET-PEESE
-  if((is.prior.PET(x) | is.prior.PEESE(x)) | !individual){
-    if(inherits(plot_data, "density.prior.PET") | inherits(plot_data, "density.prior.PEESE")){
+  if((is.prior.PET(x) | is.prior.PEESE(x))){
+    if(!individual){
       .lines.prior.PETPEESE(plot_data, ...)
     }else if(inherits(plot_data, "density.prior.simple")){
       .lines.prior.simple(plot_data, ...)
@@ -616,6 +670,11 @@ lines.prior <- function(x, xlim = NULL, x_seq = NULL, x_range_quant = NULL, n_po
     return(invisible())
   }
 
+  # plot orthonormal
+  if(is.prior.orthonormal(x)){
+    .lines.prior.orthonormal(plot_data, ...)
+    return(invisible())
+  }
 
   # default prior plots
   if(is.prior.simple(x)){
@@ -694,6 +753,13 @@ geom_prior  <- function(x, xlim = NULL, x_seq = NULL, x_range_quant = NULL, n_po
   }
 
 
+  # plot orthonormal prior
+  if(is.prior.orthonormal(x)){
+    geom <- .geom_prior.orthonormal(plot_data, ...)
+    return(geom)
+  }
+
+
   # default prior plots
   if(is.prior.simple(x)){
     if(inherits(plot_data, "density.prior.simple")){
@@ -787,6 +853,29 @@ geom_prior  <- function(x, xlim = NULL, x_seq = NULL, x_range_quant = NULL, n_po
   graphics::lines(plot_data$x, plot_data$y, lwd = lwd, lty = lty, col = col)
 
 
+  return(invisible())
+}
+.lines.prior.orthonormal     <- function(plot_data, ...){
+
+  dots      <- list(...)
+  col       <- if(!is.null(dots[["col"]]))      dots[["col"]]      else .plot.prior_settings()[["col"]]
+  lwd       <- if(!is.null(dots[["lwd"]]))      dots[["lwd"]]      else .plot.prior_settings()[["lwd"]]
+  lty       <- if(!is.null(dots[["lty"]]))      dots[["lty"]]      else .plot.prior_settings()[["lty"]]
+
+
+  graphics::lines(x = plot_data$x, y = plot_data$y, type = "l", lwd = lwd, lty = lty, col = col)
+
+  return(invisible())
+}
+.lines.prior.factor          <- function(plot_data, ...){
+
+  dots <- list(...)
+  col  <- if(!is.null(dots[["col"]][dots[["level"]]])) dots[["col"]][dots[["level"]]] else .plot.prior_settings()[["col"]]
+  lty  <- if(!is.null(dots[["lty"]][dots[["level"]]])) dots[["lty"]][dots[["level"]]] else .plot.prior_settings()[["lty"]]
+  lwd  <- if(!is.null(dots[["lwd"]]))                  dots[["lwd"]]                  else .plot.prior_settings()[["lwd"]]
+
+  graphics::lines(x = plot_data$x, y = plot_data$y, type = "l", lwd = lwd, lty = lty, col = col)
+
   return(invisible())
 }
 
@@ -911,3 +1000,51 @@ geom_prior  <- function(x, xlim = NULL, x_seq = NULL, x_range_quant = NULL, n_po
 
   return(geom)
 }
+.geom_prior.orthonormal      <- function(plot_data, ...){
+
+  dots      <- list(...)
+  col       <- if(!is.null(dots[["col"]]))      dots[["col"]]      else .plot.prior_settings()[["col"]]
+  lwd       <- if(!is.null(dots[["size"]]))     dots[["size"]]     else  if(!is.null(dots[["lwd"]])) dots[["lwd"]] else .plot.prior_settings()[["lwd"]]
+  lty       <- if(!is.null(dots[["linetype"]])) dots[["linetype"]] else  if(!is.null(dots[["lty"]])) dots[["lty"]] else .plot.prior_settings()[["lty"]]
+
+  geom <- ggplot2::geom_line(
+    data    = data.frame(
+      x = plot_data$x,
+      y = plot_data$y),
+    mapping = ggplot2::aes_string(
+      x = "x",
+      y = "y"),
+    size = lwd, linetype = lty, color = col)
+
+  return(geom)
+}
+.geom_prior.factors          <- function(plot_data, ...){
+
+  # this function notably differs from the .line_prior.factor counterpart
+  # - it's so much more difficult to draw custom legend in ggplot2 ... :(
+
+  dots <- list(...)
+  col  <- if(!is.null(dots[["col"]]))      dots[["col"]]      else rep(.plot.prior_settings()[["col"]], length(dots[["level_names"]]))
+  lty  <- if(!is.null(dots[["linetype"]])) dots[["linetype"]]
+  else  if(!is.null(dots[["lty"]]))        dots[["lty"]]      else rep(.plot.prior_settings()[["lty"]], length(dots[["level_names"]]))
+  lwd  <- if(!is.null(dots[["size"]]))     dots[["size"]]
+  else  if(!is.null(dots[["lwd"]]))        dots[["lwd"]]      else .plot.prior_settings()[["lwd"]]
+
+  names(col) <- dots[["level_names"]]
+  names(lty) <- dots[["level_names"]]
+
+  geom <- list(
+    ggplot2::geom_line(
+      data    = plot_data,
+      mapping = ggplot2::aes_string(
+        x        = "x",
+        y        = "y",
+        color    = "level",
+        linetype = "level",
+        group    = "level"),
+      size = 1, show.legend = dots[["legend"]]),
+    ggplot2::scale_linetype_manual(name = "level", values = lty),
+    ggplot2::scale_color_manual(name = "level", values = col))
+
+  return(geom)
+}
